@@ -131,15 +131,15 @@ pub type KerberosFlags = BitString;
 #[derive(AsnType, Clone, Debug, Decode, Encode, PartialEq, Eq, PartialOrd, Ord, Hash)]
 pub struct EncryptedData {
     /// Identifies which encryption algorithm was used to encipher the cipher.
-    #[rasn(tag(0))]
+    #[rasn(tag(explicit(0)))]
     pub etype: i32,
     /// Contains the version number of the key under which data is encrypted.
     /// It is only present in messages encrypted under long lasting keys, such
     /// as principals' secret keys.
-    #[rasn(tag(1))]
+    #[rasn(tag(explicit(1)))]
     pub kvno: Option<u32>,
     /// Contains the enciphered text.
-    #[rasn(tag(2))]
+    #[rasn(tag(explicit(2)))]
     pub cipher: OctetString,
 }
 
@@ -602,12 +602,12 @@ impl KdcOptions {
 
 /// The initial KDC response.
 #[derive(AsnType, Clone, Debug, Decode, Encode, PartialEq, Eq, PartialOrd, Ord, Hash)]
-#[rasn(tag(explicit(application, 11), delegate))]
+#[rasn(tag(explicit(application, 11)), delegate)]
 pub struct AsRep(pub KdcRep);
 
 /// Subsequent KDC response.
 #[derive(AsnType, Clone, Debug, Decode, Encode, PartialEq, Eq, PartialOrd, Ord, Hash)]
-#[rasn(tag(explicit(application, 13), delegate))]
+#[rasn(tag(explicit(application, 13)), delegate)]
 pub struct TgsRep(pub KdcRep);
 
 /// The main KDC body.
@@ -1070,29 +1070,29 @@ pub struct KrbCredInfo {
     /// field specifies the life of the ticket. If the `start_time` field is
     /// absent from the ticket, then the `auth_time` field should be used in its
     /// place to determine the life of the ticket.
-    #[rasn(tag(5))]
+    #[rasn(tag(explicit(5)))]
     pub start_time: Option<KerberosTime>,
     /// The time after which the ticket will not be honored (its expiration
     /// time). Note that individual services may place their own limits on the
     /// life of a ticket and MAY reject tickets which have not yet expired. As
     /// such, this is really an upper bound on the expiration time for
     /// the ticket.
-    #[rasn(tag(6))]
+    #[rasn(tag(explicit(6)))]
     pub end_time: Option<KerberosTime>,
     /// The maximum `end_time` that may be included in a renewal. It can be
     /// thought of as the absolute expiration time for the ticket, including
     /// all renewals.
-    #[rasn(tag(7))]
+    #[rasn(tag(explicit(7)))]
     pub renew_till: Option<KerberosTime>,
     /// The realm part of the server's principal identifier.
-    #[rasn(tag(8))]
+    #[rasn(tag(explicit(8)))]
     pub srealm: Option<Realm>,
     /// All components of the name part of the server's identity, including
     /// those parts that identify a specific instance of a service.
-    #[rasn(tag(9))]
+    #[rasn(tag(explicit(9)))]
     pub sname: Option<PrincipalName>,
     /// Addresses from which the ticket can be used.
-    #[rasn(tag(10))]
+    #[rasn(tag(explicit(10)))]
     pub caddr: Option<HostAddresses>,
 }
 
